<!-- CHUNK ID: chunk_D0E62F41  CHUNK TYPE: header START_LINE:1 -->
# Suggesting Improvements to the Documentation Translations

<!-- CHUNK ID: chunk_5E99F395  CHUNK TYPE: paragraph START_LINE:3 -->
Thank you for your interest in this project! The non‑English documentation is automatically translated by large language models, so mistakes are inevitable. If you notice issues in a language you are familiar with, we warmly welcome your suggestions for improvement.

Before you start contributing, please take a moment to read the following guide to help ensure your suggestions can be smoothly accepted.

<!-- CHUNK ID: chunk_B08C64DE  CHUNK TYPE: header START_LINE:7 -->
# Submit Suggestions via Weblate

<!-- CHUNK ID: chunk_66E75B28  CHUNK TYPE: paragraph START_LINE:9 -->
We use [Weblate](https://weblate.org/) to manage our documentation translations. You can check the current translation status and submit suggestions on the [project's Weblate page](https://hosted.weblate.org/projects/pdfmathtranslate-next/).

<!-- CHUNK ID: chunk_800CE400  CHUNK TYPE: header START_LINE:11 -->
## How to submit a suggestion

<!-- CHUNK ID: chunk_B3B32731  CHUNK TYPE: paragraph START_LINE:13 -->
It's very simple to propose translation improvements via Weblate, and you don't even need to register an account. Read on for the step-by-step process.

Assume you want to improve the first sentence in the "Command-line arguments" section of [Advanced → Advanced](docs/en/advanced/advanced.md):

<!-- CHUNK ID: chunk_3B565B8D  CHUNK TYPE: list START_LINE:17 -->
1. Open the [project's Weblate page](https://hosted.weblate.org/projects/pdfmathtranslate-next/).

2. Click `Search` at the top.

<!-- CHUNK ID: chunk_05247CE4  CHUNK TYPE: image START_LINE:21 -->
<img src="./../../images/weblate/homepage.png" width="420px" alt="homepage"/>

<!-- CHUNK ID: chunk_961D5AD9  CHUNK TYPE: list START_LINE:23 -->
3. In "Filter", enter the text segment you want to find. Partial text is fine.

<!-- CHUNK ID: chunk_12ED1BC8  CHUNK TYPE: image START_LINE:25 -->
<img src="./../../images/weblate/search.png" alt="search"/>

<!-- CHUNK ID: chunk_7F95E46F  CHUNK TYPE: paragraph START_LINE:27 -->
When you're done, press <kbd>Enter</kbd>.

<!-- CHUNK ID: chunk_49D0E074  CHUNK TYPE: list START_LINE:29 -->
4. After pressing <kbd>Enter</kbd>, you'll be taken to the search results page. Click the result you prefer to open the edit view.

<!-- CHUNK ID: chunk_FF937AAB  CHUNK TYPE: image START_LINE:31 -->
<img src="./../../images/weblate/search-result.png" alt="search result"/>

<!-- CHUNK ID: chunk_89F91031  CHUNK TYPE: list START_LINE:33 -->
5. In the edit view, make your changes to the translation. When finished, click <kbd>Suggest</kbd>. That's it—you've successfully completed a contribution.

<!-- CHUNK ID: chunk_1E354AB2  CHUNK TYPE: image START_LINE:35 -->
<img src="./../../images/weblate/suggestion.png" alt="suggestion"/>

<!-- CHUNK ID: chunk_998E5059  CHUNK TYPE: paragraph START_LINE:37 -->
We will review your suggestion after it's submitted. Once approved, your changes will appear in the documentation.